# -*- coding: utf-8 -*-
#*******************************************************************************
#**  This file is part of HgWeb Manager.                                     ***
#**                                                                          ***
#**  Copyright (C) 2014                                                      ***
#**  CodeGNU Solutions <Licensing _AT_ CodeGNU _DOT_ com>                    ***
#**                                                                          ***
#**  This program is free software: you can redistribute it and/or modify it ***
#**  under the terms of the GNU Affero General Public License as published   ***
#**  by the Free Software Foundation, either version 3 of the License, or    ***
#**  (at your option) any later version.                                     ***
#**                                                                          ***
#**  This program is distributed in the hope that it will be useful, but     ***
#**  WITHOUT ANY WARRANTY; without even the implied warranty of              ***
#**  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.                    ***
#**  See the GNU Affero General Public License for more details.             ***
#**                                                                          ***
#**  You should have received a copy of the GNU Affero General Public License***
#**  along with this program. If not, see <http://www.gnu.org/licenses/>.    ***
#*******************************************************************************

"""
 IMPORTS
"""
from hwm import settings


class Repository(object):
	# The directory name of the managed repository.
	__storageName = None
	# The displayed web-site name of the managed repository.
	__displayName = None
	# The displayed web-site description of the managed repository.
	__description = None
	# The displayed web-site contact information of the managed repository.
	__contact = None

	@property
	def StorageName(self):
		""" Gets the name of the directory where the managed repository is located. """
		return self.__storageName
	@StorageName.setter
	def StorageName(self, value):
		""" Sets the name of the directory with a supplied name. """
		self.__storageName = value

	@property
	def DisplayName(self):
		""" Gets the name to display for the managed repository. """
		return self.__displayName
	@DisplayName.setter
	def DisplayName(self, value):
		""" Sets the name of the managed repository to display. """
		self.__displayName = value

	@property
	def Description(self):
		""" Gets the description of the managed repository. """
		return self.__description
	@Description.setter
	def Description(self, value):
		""" Sets the description of the managed repository to display. """
		self.__description = value

	@property
	def Contact(self):
		""" Gets the contact point for the managed repository. """
		return self.__contact
	@Contact.setter
	def Contact(self, value):
		""" Sets the contact point for the managed repository. """
		self.__contact = value

	def __init__(self, repoName=None):
		""" Initialises the object with the values from a managed repository

		 @param[in] repoName	The storage name of the managed repository
							 to load.
		"""
		from mercurial import ui, hg, error
		import os

		self.__storageName = repoName
		if repoName:
			try:
				repo = hg.repository(ui.ui(), settings.RepositoryPath + os.sep + repoName)
				self.__displayName = repo.ui.config('web', 'name', default=None)
				self.__description = repo.ui.config('web', 'description', default=None)
				self.__contact = repo.ui.config('web', 'contact', default=None)
			except error.RepoError:
				self.__displayName = None
				self.__description = None
				self.__contact = None
		else:
			self.__displayName = None
			self.__description = None
			self.__contact = None

	def __eq__(self, other):
		""" Determines if two repositories are the same repository.

		 @param[in] other	The repository on the right-hand-side of the
						 equality operator to compare against.

		 @return Gives true when both repositories represent the same one,
		  else-wise gives false.
		"""
		return self.__storageName == other.__storageName
